@@ -47,7 +47,7 @@
 #'  must have column names (see Details below). Preprocessing using
 #'  the \code{preProcess} argument only supports matrices or data
 #'  frames. When using the recipe method, \code{x} should be an
-#'  unprepared \code{\link{recipe}} object that describes the model
+#'  unprepared [recipes::recipe()] object that describes the model
 #'  terms (i.e. outcome, predictors, etc.) as well as any
 #'  pre-processing that should be done to the data. This is an
 #'  alternative approach to specifying the model. Note that, when
@@ -345,7 +345,7 @@ train.default <- function(x, y,
       stop(paste("Model", method, "is not in caret's built-in library"), call. = FALSE)
   }
   checkInstall(models$library)
-  for(i in seq(along = models$library)) do.call("requireNamespaceQuietStop", list(package = models$library[i]))
+  for(i in seq(along.with = models$library)) do.call("requireNamespaceQuietStop", list(package = models$library[i]))
   if(any(names(models) == "check") && is.function(models$check)) {
     software_check <- models$check(models$library)
   }
@@ -585,7 +585,7 @@ train.default <- function(x, y,
     ##         tmp <- vector(mode = "list", length = nrow(param) + 1)
     ##         tmp[[1]] <- out
     ##
-    ##         for(j in seq(along = param$.n.trees))
+    ##         for(j in seq(along.with = param$.n.trees))
     ##           {
     ##             tmp[[j]]  <- predict(modelFit,
     ##                                  newdata,
@@ -816,7 +816,7 @@ train.default <- function(x, y,
 
   ## Reorder rows of performance
   orderList <- list()
-  for(i in seq(along = paramNames)) orderList[[i]] <- performance[,paramNames[i]]
+  for(i in seq(along.with = paramNames)) orderList[[i]] <- performance[,paramNames[i]]
 
   performance <- performance[do.call("order", orderList),]
 
@@ -831,7 +831,7 @@ train.default <- function(x, y,
 
   ## Make the final model based on the tuning results
 
-  indexFinal <- if(is.null(trControl$indexFinal)) seq(along = y) else trControl$indexFinal
+  indexFinal <- if(is.null(trControl$indexFinal)) seq(along.with = y) else trControl$indexFinal
 
   if(!(length(trControl$seeds) == 1 && is.na(trControl$seeds))) set.seed(trControl$seeds[[length(trControl$seeds)]][1])
   startFinalTime <- proc.time()
@@ -944,6 +944,7 @@ train.formula <- function (form, data, ..., weights, subset, na.action = na.fail
 
   # do we need the double colon here?
   m[[1]] <- quote(stats::model.frame)
+  names(m)[names(m) == "form"] <- "formula" # avoid warning under warnPartialMatchArgs=TRUE
   m <- eval.parent(m)
   if(nrow(m) < 1) stop("Every row has at least one missing value were found", call. = FALSE)
   Terms <- attr(m, "terms")
@@ -1012,7 +1013,7 @@ train.recipe <- function(x,
       stop(paste("Model", method, "is not in caret's built-in library"), call. = FALSE)
   }
   checkInstall(models$library)
-  for(i in seq(along = models$library))
+  for(i in seq(along.with = models$library))
     do.call("requireNamespace", list(package = models$library[i]))
   if(any(names(models) == "check") && is.function(models$check)) {
     software_check <- models$check(models$library)
@@ -1410,7 +1411,7 @@ train.recipe <- function(x,
 
   ## Reorder rows of performance
   orderList <- list()
-  for(i in seq(along = paramNames)) orderList[[i]] <- performance[,paramNames[i]]
+  for(i in seq(along.with = paramNames)) orderList[[i]] <- performance[,paramNames[i]]
 
   performance <- performance[do.call("order", orderList),]
 
@@ -1425,7 +1426,7 @@ train.recipe <- function(x,
 
   ## Make the final model based on the tuning results
   indexFinal <- if(is.null(trControl$indexFinal))
-    seq(along = data[[y_orig_val]]) else trControl$indexFinal
+    seq(along.with = data[[y_orig_val]]) else trControl$indexFinal
 
   if(!(length(trControl$seeds) == 1 && is.na(trControl$seeds)))
     set.seed(trControl$seeds[[length(trControl$seeds)]][1])
